@@ -1,13 +1,13 @@
 import json
 import typing
-from importlib.resources import as_file, files
+
+from pkg_resources import resource_stream
 
 
 class Config:
     def __init__(self):
-        with as_file(files('trakit.data').joinpath('config.json')) as f:
-            cfg: typing.Mapping[str, typing.Any] = json.loads(f.read_text(encoding='utf-8'))
-
+        with resource_stream('trakit', 'data/config.json') as f:
+            cfg: typing.Mapping[str, typing.Any] = json.load(f)
         self.ignored: typing.Set[str] = set(cfg.get('ignored', []))
         self.countries: typing.Mapping[str, str] = cfg.get('countries', {})
         self.languages: typing.Mapping[str, str] = cfg.get('languages', {})
